.. currentmodule:: pandas
.. _compare_with_r:

*******************************
Comparison with R / R libraries
*******************************

Since pandas aims to provide a lot of the data manipulation and analysis
functionality that people use R for, this page was started to provide a more
detailed look at the R language and it's many 3rd party libraries as they
relate to pandas. In offering comparisons with R and CRAN libraries, we care
about the following things:

  - **Functionality / flexibility**: what can / cannot be done with each tool
  - **Performance**: how fast are operations. Hard numbers / benchmarks are
    preferable
  - **Ease-of-use**: is one tool easier or harder to use (you may have to be
    the judge of this given side-by-side code comparisons)

As I do not have an encyclopedic knowledge of R packages, feel free to suggest
additional CRAN packages to add to this list. This is also here to offer a big
of a translation guide for users of these R packages.

data.frame
----------

zoo
---

xts
---

plyr
----

reshape / reshape2
------------------

